@@ -33,6 +33,7 @@ def run_tests(generator, root, withdata=False, cpp=True, python=True, php=True,
                            out_directory=out_directory,
                            formats=serialized_format,
                            join_to_one_file=join_to_one_file,
+                           generate_ref_counter=True
                            )
         if withdata:
             generator.generate_data(data_directory=root + 'data_%s/' % serialized_format,
@@ -116,6 +117,17 @@ def test_virtual_methods():
     return 0
 
 
+def test_console():
+    if sys.version_info[0] == 2:
+        return
+    python = 'python3'
+    command = 'cd {1}/tests/test_console_compile; {0} run.py'.format(python, get_root())
+    result = os.system(command)
+    if 0 != result:
+        sys.exit(1)
+    return 0
+
+
 if __name__ == '__main__':
     if len(sys.argv) == 1:
         simple_test()
@@ -123,6 +135,7 @@ if __name__ == '__main__':
         test_functions()
         unit_tests_generator()
         test_virtual_methods()
+        test_console()
     else:
         exec(sys.argv[1])
 
